==> antlr4-editor-1.0.31.tgz: package/docs/interfaces/_decoration_rule_decoration_.ruledecoration.md <==
[antlr4-editor](../README.md) > ["decoration/rule-decoration"](../modules/_decoration_rule_decoration_.md) > [RuleDecoration](../interfaces/_decoration_rule_decoration_.ruledecoration.md)

# Interface: RuleDecoration

## Hierarchy

**RuleDecoration**

## Implemented by

* [CodeMirrorRuleDecoration](../classes/_implementions_codemirror_decoration_codemirror_rule_decoration_.codemirrorruledecoration.md)

## Index

### Properties

* [clearOnEnter](_decoration_rule_decoration_.ruledecoration.md#clearonenter)
* [toggleOnExit](_decoration_rule_decoration_.ruledecoration.md#toggleonexit)

### Methods

* [getDomElement](_decoration_rule_decoration_.ruledecoration.md#getdomelement)
* [getRule](_decoration_rule_decoration_.ruledecoration.md#getrule)
* [hide](_decoration_rule_decoration_.ruledecoration.md#hide)
* [isHidden](_decoration_rule_decoration_.ruledecoration.md#ishidden)
* [remove](_decoration_rule_decoration_.ruledecoration.md#remove)
* [show](_decoration_rule_decoration_.ruledecoration.md#show)

---

## Properties

<a id="clearonenter"></a>

###  clearOnEnter

**● clearOnEnter**: *`boolean`*

___
<a id="toggleonexit"></a>

###  toggleOnExit

**● toggleOnExit**: *`boolean`*

___

## Methods

<a id="getdomelement"></a>

###  getDomElement

▸ **getDomElement**(): `HTMLElement`

**Returns:** `HTMLElement`

___
<a id="getrule"></a>

###  getRule

▸ **getRule**(): `AntlrRuleWrapper`

**Returns:** `AntlrRuleWrapper`

___
<a id="hide"></a>

###  hide

▸ **hide**(): `void`

**Returns:** `void`

___
<a id="ishidden"></a>

###  isHidden

▸ **isHidden**(): `boolean`

**Returns:** `boolean`

___
<a id="remove"></a>

###  remove

▸ **remove**(): `void`

**Returns:** `void`

___
<a id="show"></a>

###  show

▸ **show**(): `void`

**Returns:** `void`

___

==> antlr4-editor-1.0.56.tgz: package/docs/interfaces/_decoration_rule_decoration_.ruledecoration.md <==
[antlr4-editor](../README.md) > ["decoration/rule-decoration"](../modules/_decoration_rule_decoration_.md) > [RuleDecoration](../interfaces/_decoration_rule_decoration_.ruledecoration.md)

# Interface: RuleDecoration

## Hierarchy

**RuleDecoration**

## Implemented by

* [CodeMirrorRuleDecoration](../classes/_implementations_codemirror_decoration_codemirror_rule_decoration_.codemirrorruledecoration.md)

## Index

### Properties

* [clearOnEnter](_decoration_rule_decoration_.ruledecoration.md#clearonenter)
* [toggleOnExit](_decoration_rule_decoration_.ruledecoration.md#toggleonexit)

### Methods

* [getDomElement](_decoration_rule_decoration_.ruledecoration.md#getdomelement)
* [getRule](_decoration_rule_decoration_.ruledecoration.md#getrule)
* [hide](_decoration_rule_decoration_.ruledecoration.md#hide)
* [isHidden](_decoration_rule_decoration_.ruledecoration.md#ishidden)
* [remove](_decoration_rule_decoration_.ruledecoration.md#remove)
* [show](_decoration_rule_decoration_.ruledecoration.md#show)

---

## Properties

<a id="clearonenter"></a>

###  clearOnEnter

**● clearOnEnter**: *`boolean`*

___
<a id="toggleonexit"></a>

###  toggleOnExit

**● toggleOnExit**: *`boolean`*

___

## Methods

<a id="getdomelement"></a>

###  getDomElement

▸ **getDomElement**(): `HTMLElement`

**Returns:** `HTMLElement`

___
<a id="getrule"></a>

###  getRule

▸ **getRule**(): `AntlrRuleWrapper`

**Returns:** `AntlrRuleWrapper`

___
<a id="hide"></a>

###  hide

▸ **hide**(): `void`

**Returns:** `void`

___
<a id="ishidden"></a>

###  isHidden

▸ **isHidden**(): `boolean`

**Returns:** `boolean`

___
<a id="remove"></a>

###  remove

▸ **remove**(): `void`

**Returns:** `void`

___
<a id="show"></a>

###  show

▸ **show**(): `void`

**Returns:** `void`

___
